============
Installation
============

At the command line:

.. code-block:: console

   $ pip install openstack-doc-tools

Or, if you have virtualenvwrapper installed:

.. code-block:: console

   $ mkvirtualenv openstack-doc-tools
   $ pip install openstack-doc-tools
